@@ -8,7 +8,6 @@ logger = logging.getLogger(__name__)
 
 
 class BaseService(object):
-    session = None
 
     def __init__(self, api, **config):
         self.api = api
@@ -18,38 +17,31 @@ class BaseService(object):
         }
         self.config.update(config)
 
-    def get_session(self):
-        if self.session is None:
-            self.session = requests.session()
-            self.session.auth = (self.config.get('username'),
-                                 self.config.get('password'))
-        return self.session
-
-    def __del__(self):
-        if self.session is not None:
-            self.session.close()
-
     def raise_for_status(self, request):
         try:
             request.raise_for_status()
         except requests.models.HTTPError as e:
             raise APIError(e)
 
-    def request(self, verb, method, **kwargs):
-        verb = verb.upper()
+    def _make_request(self, verb, url, params={}):
         request_kwargs = {
             'headers': {
                 'User-Agent': self.config['user_agent'],
             },
             'timeout': self.config.get('timeout', 30),
         }
+        if 'username' in self.config:
+            request_kwargs['auth'] = (self.config.get('username', ''),
+                                      self.config.get('password', ''))
         if verb == 'GET':
-            request_kwargs['params'] = kwargs
+            request_kwargs['params'] = params
         else:
-            request_kwargs['data'] = kwargs
-        url = self.config['base_url'] + method
+            request_kwargs['data'] = params
         logger.debug('%s %s' % (verb, url))
-        r = self.get_session().request(verb, url, **request_kwargs)
-        r.connection.close()
+        r = requests.request(verb, url, **request_kwargs)
         self.raise_for_status(r)
         return r.json()
+
+    def request(self, verb, method, **kwargs):
+        url = self.config['base_url'] + method
+        return self._make_request(verb.upper(), url, kwargs)
